==> prometheus-annotations-2.8.1-sources.jar: io/dekorate/prometheus/model/EndpointFluentImpl.java <==
package io.dekorate.prometheus.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class EndpointFluentImpl<A extends io.dekorate.prometheus.model.EndpointFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.dekorate.prometheus.model.EndpointFluent<A>{
  public EndpointFluentImpl() {
  }
  public EndpointFluentImpl(io.dekorate.prometheus.model.Endpoint instance) {
    this.withPort(instance.getPort()); 
    this.withPath(instance.getPath()); 
    this.withInterval(instance.getInterval()); 
    this.withHonorLabels(instance.isHonorLabels()); 
  }
  private java.lang.String port;
  private java.lang.String path;
  private java.lang.String interval;
  private boolean honorLabels;
  public java.lang.String getPort() {
    return this.port;
  }
  public A withPort(java.lang.String port) {
    this.port=port; return (A) this;
  }
  public java.lang.Boolean hasPort() {
    return this.port != null;
  }
  
  /**
   * Method is deprecated. use withPort instead.
   */
  @java.lang.Deprecated
  public A withNewPort(java.lang.String arg0) {
    return (A)withPort(new String(arg0));
  }
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  public java.lang.String getInterval() {
    return this.interval;
  }
  public A withInterval(java.lang.String interval) {
    this.interval=interval; return (A) this;
  }
  public java.lang.Boolean hasInterval() {
    return this.interval != null;
  }
  
  /**
   * Method is deprecated. use withInterval instead.
   */
  @java.lang.Deprecated
  public A withNewInterval(java.lang.String arg0) {
    return (A)withInterval(new String(arg0));
  }
  public boolean isHonorLabels() {
    return this.honorLabels;
  }
  public A withHonorLabels(boolean honorLabels) {
    this.honorLabels=honorLabels; return (A) this;
  }
  public java.lang.Boolean hasHonorLabels() {
    return true;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EndpointFluentImpl that = (EndpointFluentImpl) o;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (interval != null ? !interval.equals(that.interval) :that.interval != null) return false;
    if (honorLabels != that.honorLabels) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(port,  path,  interval,  honorLabels,  super.hashCode());
  }
  
}

==> prometheus-annotations-2.9.1-sources.jar: io/dekorate/prometheus/model/EndpointFluentImpl.java <==
package io.dekorate.prometheus.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EndpointFluentImpl<A extends EndpointFluent<A>> extends BaseFluent<A> implements EndpointFluent<A>{
  public EndpointFluentImpl() {
  }
  public EndpointFluentImpl(io.dekorate.prometheus.model.Endpoint instance) {
    this.withPort(instance.getPort()); 
    this.withPath(instance.getPath()); 
    this.withInterval(instance.getInterval()); 
    this.withHonorLabels(instance.isHonorLabels()); 
  }
  private String port;
  private java.lang.String path;
  private java.lang.String interval;
  private boolean honorLabels;
  public java.lang.String getPort() {
    return this.port;
  }
  public A withPort(java.lang.String port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  public java.lang.String getInterval() {
    return this.interval;
  }
  public A withInterval(java.lang.String interval) {
    this.interval=interval; return (A) this;
  }
  public java.lang.Boolean hasInterval() {
    return this.interval != null;
  }
  public boolean isHonorLabels() {
    return this.honorLabels;
  }
  public A withHonorLabels(boolean honorLabels) {
    this.honorLabels=honorLabels; return (A) this;
  }
  public java.lang.Boolean hasHonorLabels() {
    return true;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EndpointFluentImpl that = (EndpointFluentImpl) o;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (interval != null ? !interval.equals(that.interval) :that.interval != null) return false;
    if (honorLabels != that.honorLabels) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(port,  path,  interval,  honorLabels,  super.hashCode());
  }
  public java.lang.String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (interval != null) { sb.append("interval:"); sb.append(interval + ","); }
    sb.append("honorLabels:"); sb.append(honorLabels);
    sb.append("}");
    return sb.toString();
  }
  public A withHonorLabels() {
    return withHonorLabels(true);
  }
  
}
